"""grafana-wtf: Grep through all Grafana entities"""
__appname__ = "grafana-wtf"
__version__ = "0.12.0"
